@@ -9,8 +9,8 @@ use criterion::{black_box, criterion_group, criterion_main, Criterion};
 pub fn criterion_benchmark(c: &mut Criterion) {
     c.bench_function("logger", |b| {
         b.iter(|| {
-            eza::logger::configure(black_box(std::env::var_os(eza::options::vars::EZA_DEBUG)))
-        })
+            eza::logger::configure(black_box(std::env::var_os(eza::options::vars::EZA_DEBUG)));
+        });
     });
 }
 
