@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 //! Extended attribute support for `NetBSD`, `Darwin`, and `Linux` systems.
 
 #![allow(trivial_casts)] // for ARM
@@ -112,7 +118,7 @@ mod extended_attrs {
         }
     }
 
-    #[cfg(any(target_os = "linux"))]
+    #[cfg(target_os = "linux")]
     mod os {
         use libc::{c_char, c_void, size_t, ssize_t};
 
@@ -283,7 +289,7 @@ mod extended_attrs {
             let start = index + 1;
             let end = start + item_length;
             if end <= length {
-                result.push(OsStr::from_bytes(&buffer[start..end]).to_owned())
+                result.push(OsStr::from_bytes(&buffer[start..end]).to_owned());
             }
             index = end;
         }
@@ -473,7 +479,7 @@ mod extended_attrs {
             if let Some(name) = attr_name.to_str() {
                 let attr_name =
                     CString::new(name).map_err(|e| io::Error::new(io::ErrorKind::Other, e))?;
-                let value = get_attribute(&path, &attr_name, follow_symlinks, getter)?;
+                let value = get_attribute(path, &attr_name, follow_symlinks, getter)?;
                 attrs.push(Attribute {
                     name: format!("{namespace}::{name}"),
                     value,
@@ -666,7 +672,7 @@ struct BorrowedWriter<'a> {
     pub buffer: &'a mut Vec<u8>,
 }
 
-impl<'a> io::Write for BorrowedWriter<'a> {
+impl io::Write for BorrowedWriter<'_> {
     fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
         self.buffer.write(buf)
     }
