@@ -5,7 +5,7 @@
 // SPDX-FileCopyrightText: 2014 Benjamin Sago
 // SPDX-License-Identifier: MIT
 #[cfg(target_os = "windows")]
-pub use self::cell::{DisplayWidth, TextCell, TextCellContents};
+pub use self::cell::TextCell;
 pub use self::escape::escape;
 
 pub mod color_scale;
@@ -55,22 +55,23 @@ pub enum TerminalWidth {
 }
 
 impl TerminalWidth {
+    #[must_use]
     pub fn actual_terminal_width(self) -> Option<usize> {
         // All of stdin, stdout, and stderr could not be connected to a
         // terminal, but we’re only interested in stdout because it’s
         // where the output goes.
 
         #[cfg(unix)]
-        let stdout_term_width = {
-            use std::os::fd::AsRawFd;
-            terminal_size::terminal_size_using_fd(std::io::stdout().as_raw_fd())
-                .map(|(w, _h)| w.0 as _)
-        };
+        let stdout_term_width =
+            { terminal_size::terminal_size_of(std::io::stdout()).map(|(w, _h)| w.0 as _) };
         #[cfg(windows)]
         let stdout_term_width = {
+            use std::os::windows::io::BorrowedHandle;
             use windows_sys::Win32::System::Console::{GetStdHandle, STD_OUTPUT_HANDLE};
-            terminal_size::terminal_size_using_handle(unsafe { GetStdHandle(STD_OUTPUT_HANDLE) })
-                .map(|(w, _h)| w.0 as _)
+            terminal_size::terminal_size_of(unsafe {
+                BorrowedHandle::borrow_raw(GetStdHandle(STD_OUTPUT_HANDLE))
+            })
+            .map(|(w, _h)| w.0 as _)
         };
 
         #[rustfmt::skip]
